==> selenium-server-3.4.0-sources.jar: org/openqa/selenium/remote/server/handler/GetLogHandler.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.server.handler;

import org.openqa.selenium.logging.LogEntries;
import org.openqa.selenium.logging.LogType;
import org.openqa.selenium.remote.server.JsonParametersAware;
import org.openqa.selenium.remote.server.Session;
import org.openqa.selenium.remote.server.log.LoggingManager;

import java.util.Map;

/**
 * RestishHandler used to fetch logs from the Remote WebDriver server.
 */
public class GetLogHandler extends WebDriverHandler<LogEntries> implements JsonParametersAware {
  private volatile String type;

  public GetLogHandler(Session session) {
    super(session);
  }

  @Override
  public LogEntries call() throws Exception {
    if (LogType.SERVER.equals(type)) {
      return LoggingManager.perSessionLogHandler().getSessionLog(getSessionId());
    }
    return getDriver().manage().logs().get(type);
  }

  @Override
  public String toString() {
    return String.format("[fetching logs for: %s]", type);
  }

  public void setJsonParameters(Map<String, Object> allParameters) {
    type = (String) allParameters.get("type");
  }
}

==> selenium-server-3.141.59-sources.jar: org/openqa/selenium/remote/server/handler/GetLogHandler.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.remote.server.handler;

import org.openqa.selenium.logging.LogEntries;
import org.openqa.selenium.logging.LogType;
import org.openqa.selenium.remote.server.Session;
import org.openqa.selenium.remote.server.log.LoggingManager;

import java.util.Map;

/**
 * RestishHandler used to fetch logs from the Remote WebDriver server.
 */
public class GetLogHandler extends WebDriverHandler<LogEntries> {
  private volatile String type;

  public GetLogHandler(Session session) {
    super(session);
  }

  @Override
  public void setJsonParameters(Map<String, Object> allParameters) throws Exception {
    super.setJsonParameters(allParameters);
    type = (String) allParameters.get("type");
  }

  @Override
  public LogEntries call() throws Exception {
    if (LogType.SERVER.equals(type)) {
      return LoggingManager.perSessionLogHandler().getSessionLog(getSessionId());
    }
    return getDriver().manage().logs().get(type);
  }

  @Override
  public String toString() {
    return String.format("[fetching logs for: %s]", type);
  }

}
